@@ -8,6 +8,3 @@ export GOOGLE_CLOUD_SDK_HOME=$CLOUDSDK_ROOT_DIR
 #  CLOUDSDK_PYTHON_SITEPACKAGES  # use python site packages
 #  CLOUDSDK_BQ_PYTHON            # python interpreter for bq
 #  CLOUDSDK_ENCODING             # python io encoding for gcloud
-export CLOUDSDK_PYTHON=/opt/google-cloud-cli/platform/bundledpythonunix/bin/python3
-export CLOUDSDK_GSUTIL_PYTHON=/opt/google-cloud-cli/platform/bundledpythonunix/bin/python3
-export CLOUDSDK_BQ_PYTHON=/opt/google-cloud-cli/platform/bundledpythonunix/bin/python3
